Crate componentize_qjs

Crate componentize_qjs 

Modules

codegen
Code generation for the JS shim that bridges WIT types to the quickjs runtime.
stubwasi
WASI import stubbing for snapshotted components.

Structs

ComponentizeOpts
Options for componentizing a JavaScript source file.
Init
Auto-generated bindings for an instance a component which implements the world init.
InitIndices
Auto-generated bindings for index of the exports of init.
InitPre
Auto-generated bindings for a pre-instantiated version of a component which implements the world init.

Enums

Runtime
QuickJS runtime variant to embed in the generated component.

Functions

componentize
Convert JavaScript source code into a WebAssembly component.
default_builtin_runtime
Return the built-in runtime selected by Cargo features.
default_runtime_wasm
Return the built-in default runtime Wasm bytes.
default_sync_runtime_wasm
Return the built-in non-async runtime Wasm bytes.
opt_size_runtime_wasm
Return the built-in opt-size runtime Wasm bytes.
opt_size_sync_runtime_wasm
Return the built-in non-async opt-size runtime Wasm bytes.