pub enum Runtime<'a> {
Default,
OptSize,
DefaultSync,
OptSizeSync,
Custom(&'a [u8]),
}Expand description
QuickJS runtime variant to embed in the generated component.
Variants
Default
Standard runtime optimized for speed.
Built with component-model async support when the component-model-async
feature is enabled (the default); otherwise this is the non-async runtime.
OptSize
Runtime optimized for smaller generated components.
Built with component-model async support when the component-model-async
feature is enabled (the default); otherwise this is the non-async runtime.
DefaultSync
Non-async runtime optimized for speed.
Produces components that do not use the component-model async ABI, so they run on hosts without async support. Always available regardless of Cargo features.
OptSizeSync
Non-async runtime optimized for smaller generated components.
Produces components that do not use the component-model async ABI, so they run on hosts without async support. Always available regardless of Cargo features.
Custom(&'a [u8])
Caller-provided runtime Wasm bytes.