pub struct Init { /* private fields */ }Expand description
Auto-generated bindings for an instance a component which
implements the world init.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Init::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
InitPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesInitPre::instantiateto create aInit. -
If you’ve instantiated the instance yourself already then you can use
Init::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Init
impl Init
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Init>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<Init>
Convenience wrapper around InitPre::new and
InitPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Init>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Init>
Convenience wrapper around InitIndices::new and
InitIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Init>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Init>where
_T: Send,
Convenience wrapper around InitPre::new and
InitPre::instantiate_async.
pub async fn call_init<S: AsContextMut>( &self, store: S, arg0: &str, arg1: &str, arg2: bool, ) -> Result<Result<(), String>>