Crate componentize_qjs

Crate componentize_qjs 

Modules

codegen
Code generation for the JS shim that bridges WIT types to the quickjs runtime.
stubwasi
WASI import stubbing for snapshotted components.

Structs

ComponentizeOpts
Options for componentizing a JavaScript source file.
Init
Auto-generated bindings for an instance a component which implements the world init.
InitIndices
Auto-generated bindings for index of the exports of init.
InitPre
Auto-generated bindings for a pre-instantiated version of a component which implements the world init.

Functions

componentize
Convert JavaScript source code into a WebAssembly component.